**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             Primal1
Sequence         1 - Introduction to mathematical programming using GAMS
Type             LP
GAMS language    Computed parameter
Description
Adding gross margin calculation
" A given farm can produce two crops: wheat and maize.
We are looking to determine the area dedicated to each crop, knowing that:
The farmer's objective is to maximize his income
The yield of wheat is 5 tonnes per hectar eand that of maize 10 tonnes.
Their production costs are 300/ha and 500/ha, respectively.
Both cereals are sold at 150/tonne.
Wheat requires 25 hours of labour per hectare and per year and maize 50 hours of labour .
The area of the farm is 50 ha and the farmer can work 2000 hours in a year.  "

$Offtext
*-----------------------------------------------------------------------------*


*----------                         DECLARATIONS                    ----------*
sets
C crops  /wheat,maize/
;

*----------                          DATA                        ----------*
scalar
LAND_A      land availability in hectares                 /50/
LABOUR_A    labour availability in hours                 /2000/
;

parameter
LN(C) labour needs per hectare and per crop (hours)
/wheat   25
 maize   50/

YLD (C) yield per crop in tonnes per hectare
/ wheat 5
 maize 10/

PC (C) selling price per crop in euros
/ wheat 150
 maize 150/

COST (C) cost per crop in euros per ha
/ wheat 300
 maize 500/
;

parameter
GM(C) gross margin per crop in euros    ;
GM(C) = YLD(C)*PC(C)-COST(C);

*----------                         MODEL                          ----------*
variables
Z   total fram income  (euros)
;

positive variables
X area per crop (hectares)
;

equations
OBJECTIVE       objective function
LAND            land equation
LABOUR          labour equation
;

OBJECTIVE..    sum(c, GM(c)*X(c)) =E= Z ;

LAND..         sum(c, X(c)) =l= LAND_A ;

LABOUR..       sum(c, LN(c)*X(c)) =L= LABOUR_A  ;


model example first example /all/;

*----------                        SOLUTION                         ----------*
solve example using LP maximizing Z;

*For the marginal value of the labour equation
display LABOUR.m ;

*For the optimum value of the crop surfaces
display x.l ;

*For the minimum value of the land equation
display LAND.lo ;

*For the gross margin parameter
display GM ;
